heamy package
=============

Subpackages
-----------

.. toctree::

    heamy.utils

Submodules
----------

heamy.cache module
------------------

.. automodule:: heamy.cache
    :members:
    :undoc-members:
    :show-inheritance:

heamy.dataset module
--------------------

.. automodule:: heamy.dataset
    :members:
    :undoc-members:
    :show-inheritance:

heamy.estimator module
----------------------

.. automodule:: heamy.estimator
    :members:
    :undoc-members:
    :show-inheritance:

heamy.feature module
--------------------

.. automodule:: heamy.feature
    :members:
    :undoc-members:
    :show-inheritance:

heamy.pipeline module
---------------------

.. automodule:: heamy.pipeline
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: heamy
    :members:
    :undoc-members:
    :show-inheritance:
